@@ -8,7 +8,7 @@ from restclients_core.exceptions import DataFailureException
 from restclients_core.dao import MockDAO
 from uw_adsel.dao import ADSEL_DAO
 from uw_adsel.models import Major, Cohort, Quarter, Activity, Application, \
-    Decision
+    Decision, AdminMajor, AdminCohort
 import dateutil.parser
 from datetime import datetime
 import urllib.parse
@@ -221,6 +221,9 @@ class AdSel(object):
             cohort_model.protected_group = cohort['protectedGroupInd']
             cohort_model.active_cohort = cohort['activeCohortInd']
             cohort_model.assigned_count = cohort['assignedCount']
+            cohort_model.assigned_freshman = cohort['freshmanCount']
+            cohort_model.assigned_transfer = cohort['transferCount']
+            cohort_model.assigned_postbac = cohort['postBacCount']
             cohorts.append(cohort_model)
         return cohorts
 
@@ -289,8 +292,121 @@ class AdSel(object):
             major.assigned_nonresident = major_data['nonResidentCount']
         except KeyError:
             pass
+        try:
+            major.assigned_freshman = major_data['freshmanCount']
+            major.assigned_transfer = major_data['transferCount']
+            major.assigned_postbac = major_data['postBacCount']
+        except KeyError:
+            pass
         return major
 
+    def get_admin_majors(self):
+        url = "{}/admin/majors".format(self.API)
+        response = self._get_resource(url)
+        majors = self._majors_from_admin_majors(response)
+        return majors
+
+    def get_admin_major_by_id(self, id):
+        url = "{}/admin/major/{}".format(self.API, id)
+        response = self._get_resource(url)
+        major = self._major_from_admin_major(response)
+        return major
+
+    def _majors_from_admin_majors(self, response):
+        majors = []
+        for major in response:
+            majors.append(self._major_from_admin_major(major))
+        return majors
+
+    def _major_from_admin_major(self, response):
+        major_data = {'major_id': response['id'],
+                      'major_abbr': response['majorAbbr'],
+                      'begin_academic_qtr_key_id':
+                          response['beginAcademicQtrKeyId'],
+                      'end_academic_qtr_key_id':
+                          response['endAcademicQtrKeyId'],
+                      'major_pathway': response['majorPathway'],
+                      'display_name': response['displayName'],
+                      'college': response['collegeCode'],
+                      'division': response['collegeDivision'],
+                      'dtx': response['directToXType'],
+                      'dtx_desc': response['directToXDesc'],
+                      'directToMajorInd': response['directToMajorInd'],
+                      'directToCollegeInd': response['directToCollegeInd'],
+                      'majorDegreeLevel': response['majorDegreeLevel'],
+                      'majorDegreeType': response['majorDegreeType'],
+                      'assignedMajorAbbr': response['assignedMajorAbbr'],
+                      'assignedMajorDegreeLevel':
+                          response['assignedMajorDegreeLevel'],
+                      'assignedMajorDegreeType':
+                          response['assignedMajorDegreeType'],
+                      'majorAssignedName': response['majorAssignedName'],
+                      'assignedMajorPathway': response['assignedMajorPathway'],
+                      }
+        return AdminMajor(**major_data)
+
+    def get_admin_majorvalues(self):
+        url = "{}/admin/majorvalues".format(self.API)
+        response = self._get_resource(url)
+        return response
+
+    def post_admin_major(self, major):
+        url = "{}/admin/major".format(self.API)
+        return self._post_resource(url, major.json_data())
+
+    def put_admin_major(self, major):
+        url = "{}/admin/major".format(self.API)
+        return self._put_resource(url, major.json_data())
+
+    def get_admin_cohorts_by_qtr(self, qtr):
+        url = "{}/admin/cohorts/{}".format(self.API, qtr)
+        response = self._get_resource(url)
+        cohorts = self._cohorts_from_admin_cohorts(response)
+        return cohorts
+
+    def get_admin_cohort_by_qtr_id(self, qtr, id):
+        url = "{}/admin/cohorts/{}/{}".format(self.API, qtr, id)
+        response = self._get_resource(url)
+        cohort = self._cohort_from_admin_cohort(response)
+        return cohort
+
+    def _cohorts_from_admin_cohorts(self, response):
+        cohorts = []
+        for cohort in response:
+            cohorts.append(self._cohort_from_admin_cohort(cohort))
+        return cohorts
+
+    def _cohort_from_admin_cohort(self, response):
+        cohort_data = {"academic_qtr_id": response['academicQtrKeyId'],
+                       "cohort_number": response['cohortNbr'],
+                       "cohort_description": response['cohortDescription'],
+                       "cohort_residency": response['cohortResidency'],
+                       "cohort_campus": response['cohortCampus'],
+                       "cohort_application_type":
+                           response['cohortApplicationType'],
+                       "admit_decision": response['admitDecision'],
+                       "protected_group": response['protectedGroupInd'],
+                       "enforce_exceptions": response['enforceExceptionsInd'],
+                       "active_cohort": response['activeCohortInd'],
+                       "record_updated": response['recordUpdateDateTime'],
+                       "record_update_user": response['recordUpdateUser'],
+                       }
+        return AdminCohort(**cohort_data)
+
+    def post_admin_cohort(self, cohort):
+        url = "{}/admin/cohort".format(self.API)
+        return self._post_resource(url, cohort.json_data())
+
+    def put_admin_cohort(self, cohort):
+        url = "{}/admin/cohort".format(self.API)
+        return self._put_resource(url, cohort.json_data())
+
+    def copy_cohort(self, from_cohort_id, to_cohort_id):
+        url = "{}/admin/cohort/copy/{}/{}".format(self.API,
+                                                  from_cohort_id,
+                                                  to_cohort_id)
+        return self._post_resource(url, {})
+
     def _get_resource(self, url):
         response = self.DAO.getURL(url, self._headers())
 
@@ -310,6 +426,16 @@ class AdSel(object):
 
         return json.loads(response.data)
 
+    def _put_resource(self, url, request):
+        response = self.DAO.putURL(url,
+                                   self._post_headers(),
+                                   body=json.dumps(request))
+        if response.status not in [200, 201]:
+            self._log_error(url, response)
+            raise DataFailureException(url, response.status, response.data)
+
+        return json.loads(response.data)
+
     def _headers(self):
         headers = {"Accept": "application/json"}
         return headers
